@@ -317,8 +317,11 @@ void KGrSLDialog::setupWidgets()
 
     connect(games, &QTreeWidget::itemSelectionChanged, this, &KGrSLDialog::slGame);
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     connect(display, static_cast<void (QSpinBox::*)(const QString &)>(&QSpinBox::valueChanged), this, &KGrSLDialog::slUpdate);
-
+#else
+    connect(display, &QSpinBox::textChanged, this, &KGrSLDialog::slUpdate);
+#endif
     connect(number, &QScrollBar::valueChanged, this, &KGrSLDialog::slShowLevel);
 
     // Only enable name and hint dialog here if saving a new or edited level.
@@ -448,7 +451,7 @@ void KGrSLDialog::slGame()
         }
         // Else use the last level played in the selected game (from KConfig).
         else {
-            lev = gameGroup.readEntry (QStringLiteral("Level_") + myGameList.at (n)->prefix, 1);
+            lev = gameGroup.readEntry (QLatin1String("Level_") + myGameList.at (n)->prefix, 1);
             number->setValue (lev);			// Else use level 1.
         }
         break;
